Citing HCIPy
============

If you use HCIPy for your own research, we ask you to cite the HCIPy proceeding (`Por et al. 2018 <https://ui.adsabs.harvard.edu/abs/2018SPIE10703E..42P>`__). If there is no appropriate place in the body text to cite the proceeding, please include something along the lines of the following in your acknowledgements:

    This research made use of HCIPy, an open-source object-oriented framework written in Python for performing end-to-end simulations of high-contrast imaging instruments (`Por et al. 2018 <https://ui.adsabs.harvard.edu/abs/2018SPIE10703E..42P>`__).

The BibTeX citation can be found below:

.. code-block:: bib

    @inproceedings{por2018hcipy,
        author = {Por, E.~H. and Haffert, S.~Y. and Radhakrishnan, V.~M. and Doelman, D.~S. and Van Kooten, M. and Bos, S.~P.},
        title = "{High Contrast Imaging for Python (HCIPy): an open-source adaptive optics and coronagraph simulator}",
        booktitle = {Adaptive Optics Systems VI},
        year = 2018,
        series = {Proc. {{SPIE}}},
        volume = 10703,
        doi = {10.1117/12.2314407},
        URL = {https://doi.org/10.1117/12.2314407}
    }
